summaryrefslogtreecommitdiff
path: root/findurls.go
diff options
context:
space:
mode:
Diffstat (limited to 'findurls.go')
-rw-r--r--findurls.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/findurls.go b/findurls.go
index 8f84936..000e482 100644
--- a/findurls.go
+++ b/findurls.go
@@ -8,12 +8,12 @@ import (
"golang.org/x/net/html/atom"
)
// findURLs combs htmlDoc for anchor-tag URLs. The refURL parameter is
// used to resolve each found URL into an absolute URL, and also
// ensures that we don't crawl outside refURL's parent Web domain.
//
// Return the slice of URLs.
-func findURLs(refURL url.URL, htmlDoc *html.Node) []url.URL {
+func extractURLs(refURL url.URL, htmlDoc *html.Node) []url.URL {
// Used for collecting all the URLs we find.
var rawURLs []url.URL
@@ -8,12 +8,12 @@ import (
"golang.org/x/net/html/atom"
)
-// findURLs combs htmlDoc for anchor-tag URLs. The refURL parameter is
+// extractURLs combs htmlDoc for anchor-tag URLs. The refURL parameter is
// used to resolve each found URL into an absolute URL, and also
// ensures that we don't crawl outside refURL's parent Web domain.